// Predict handler for -mybipoisson-

program define mybipoisson_p
        version 18

        syntax [anything] [if] [in] [, SCores xb1 xb2 xi1 xi2 mu1 mu2 ]

        if "`scores'" != "" {
                // Let ml_p figure it out
                ml_p `0'
                exit
        }
                
        local n : word count `anything'
        if `n' < 1 | `n' > 2 {
                exit 198
        }
        if `n' == 1 {
                local vnam `anything'
        }
        else {
                local vtyp `:word 1 of `anything''
                local vnam `:word 2 of `anything''
        }
        
        if "`xb1'`xb2'`xi1'`xi2'`mu1'`mu2'" == "" {
                di in smcl "(option {bf:xb1} assumed)"
                local xb1 xb
        }

        tempname b
        mat `b' = e(b)

        tempvar theta 
        if "`xb1'`xi1'`mu1'" != "" {
                mat score `theta' = `b' `if' `in', eq(#1)
        }
        else {
                mat score `theta' = `b' `if' `in', eq(#2)
        }

        if "`xb1'" != "" {
                generate `vtyp' `vnam' = `theta'
                lab var `vnam' "Linear combination for equation 1"
        }
        else if "`xb2'" != "" {
                generate `vtyp' `vnam' = `theta'
                lab var `vnam' "Linear combination for equation 2"
        }
        else if "`xi1'" != "" {
                generate `vtyp' `vnam' = exp(`theta')
                lab var `vnam' "Latent mean for equation 1"
        }
        else if "`xi2'" != "" {
                generate `vtyp' `vnam' = exp(`theta')
                lab var `vnam' "Latent mean for equation 2"
        }
        else {
                tempname xi0
                sca `xi0' = exp(_b[/ln_xi0])
                if "`mu1'" != "" {
                        generate `vtyp' `vnam' = exp(`theta') + `xi0'
                        lab var `vnam' ///
                                "Expected count for `:word 1 of `e(depvar)''"
                }
                else {
                       generate `vtyp' `vnam' = exp(`theta') + `xi0'
                       lab var `vnam' ///
                                "Expected count for `:word 2 of `e(depvar)''"
                }
        }

end
 
